@@ -532,6 +532,22 @@ fn create_task_env(
             },
         );
     }
+    for (item, value) in &chompfile.env_default {
+        if !env.contains_key(item) {
+            if let Some(val) = std::env::var_os(item) {
+                env.insert(item.to_uppercase(), String::from(val.to_str().unwrap()));
+            } else {
+                env.insert(
+                    item.to_uppercase(),
+                    if replacements {
+                        replace_env_vars_static(value, &env)
+                    } else {
+                        value.to_string()
+                    },
+                );
+            }
+        }
+    }
     if let Some(task_env) = task.env() {
         for (item, value) in task_env {
             env.insert(
@@ -562,22 +578,6 @@ fn create_task_env(
             }
         }
     }
-    for (item, value) in &chompfile.env_default {
-        if !env.contains_key(item) {
-            if let Some(val) = std::env::var_os(item) {
-                env.insert(item.to_uppercase(), String::from(val.to_str().unwrap()));
-            } else {
-                env.insert(
-                    item.to_uppercase(),
-                    if replacements {
-                        replace_env_vars_static(value, &env)
-                    } else {
-                        value.to_string()
-                    },
-                );
-            }
-        }
-    }
     env
 }
 
@@ -598,6 +598,18 @@ fn create_task_env(
             },
         );
     }
+    for (item, value) in &chompfile.env_default {
+        if !env.contains_key(item) && std::env::var_os(item).is_none() {
+            env.insert(
+                item.to_uppercase(),
+                if replacements {
+                    replace_env_vars_static(value, &env)
+                } else {
+                    value.to_string()
+                },
+            );
+        }
+    }
     if let Some(task_env) = task.env() {
         for (item, value) in task_env {
             env.insert(
@@ -624,18 +636,6 @@ fn create_task_env(
             }
         }
     }
-    for (item, value) in &chompfile.env_default {
-        if !env.contains_key(item) && std::env::var_os(item).is_none() {
-            env.insert(
-                item.to_uppercase(),
-                if replacements {
-                    replace_env_vars_static(value, &env)
-                } else {
-                    value.to_string()
-                },
-            );
-        }
-    }
     env
 }
 
@@ -1142,7 +1142,7 @@ impl<'a> Runner<'a> {
         let mut targets = String::new();
         for (idx, t) in task.targets.iter().enumerate() {
             if idx > 0 {
-                targets.push_str(",");
+                targets.push_str(":");
             }
             if idx == target_index {
                 targets.push_str(&target);
